@@ -30,7 +30,7 @@ async def a_row(stmt: str) -> dict | None:
     return {k: item[k] for k in item.keys()} if item else None
 
 
-async def get_rows(stmt: str) -> Iterator[dict]:
+def get_rows(stmt: str) -> Iterator[dict]:
     db = sq.connect(URL)
     db.row_factory = sq.Row
     cursor = db.execute(stmt)
